@@ -211,11 +211,13 @@ class RawGuiSettings(object):
                 'AveragedFilePath'     : [None,  get_id(), 'text'],
                 'SubtractedFilePath'   : [None,  get_id(), 'text'],
                 'BiftFilePath'         : [None,  get_id(), 'text'],
+                'DiftFilePath'         : [None,  get_id(), 'text'],
                 'GnomFilePath'         : [None,  get_id(), 'text'],
                 'AutoSaveOnImageFiles' : [False, get_id(), 'bool'],
                 'AutoSaveOnAvgFiles'   : [False, get_id(), 'bool'],
                 'AutoSaveOnSub'        : [False, get_id(), 'bool'],
                 'AutoSaveOnBift'       : [False, get_id(), 'bool'],
+                'AutoSaveOnDift'       : [False, get_id(), 'bool'],
                 'AutoSaveOnGnom'       : [False, get_id(), 'bool'],
 
                 #IMAGE FORMATS
@@ -347,6 +349,7 @@ class RawGuiSettings(object):
                 'dammifRefine'          : [True, get_id(), 'bool'],
                 'dammifProgram'         : ['DAMMIF', get_id(), 'choice'],
                 'dammifExpectedShape'   : ['u', get_id(), 'choice'],
+                'dammifModelFormat'     : ['cif', get_id(), 'choice'],
 
                 #DAMMIN settings that are not included in DAMMIF settings
                 'damminInitial'         : ['S', get_id(), 'choice'], #Initial DAM
@@ -367,6 +370,7 @@ class RawGuiSettings(object):
                 'damaverHarmonics'      : [5, get_id(), 'int'],
                 'damaverPoints'         : [51, get_id(), 'int'],
                 'damaverQmax'           : [0.51, get_id(), 'float'],
+                'damaverModelFormat'    : ['cif', get_id(), 'choice'],
 
                 #CIFSUP and SUPCOMB settings
                 'cifsupMethod'          : ['ICP', get_id(), 'choice'],
@@ -393,18 +397,30 @@ class RawGuiSettings(object):
                 'crysolHydrDensity'     : [0.03, get_id(), 'float'],
                 'crysolConstant'        : [False, get_id(), 'bool'],
                 'crysolFitSolvent'      : [True, get_id(), 'bool'],
-                'crysolEnergy'          : ['None', get_id(), 'str'],
+                'crysolEnergy'          : ['None', get_id(), 'text'],
                 'crysolShell'           : ['directional', get_id(), 'choice'],
                 'crysolExplicitH'       : [False, get_id(), 'bool'],
-                'crysolImplicitH'       : ['None', get_id(), 'str'],
-                'crysolSubElement'      : ['None', get_id(), 'str'],
-                'crysolModelID'         : ['None', get_id(), 'str'],
-                'crysolChainID'         : ['None', get_id(), 'str'],
+                'crysolImplicitH'       : ['None', get_id(), 'text'],
+                'crysolSubElement'      : ['None', get_id(), 'text'],
+                'crysolModelID'         : ['None', get_id(), 'text'],
+                'crysolChainID'         : ['None', get_id(), 'text'],
                 'crysolAltNames'        : [False, get_id(), 'bool'],
                 'crysolResultToPlot'    : ['.abs', get_id(), 'choice'],
 
+                #PDB2MRC settings
+                'pdb2mrcQmax'            : ['0.5', get_id(), 'text'],
+                'pdb2mrcNumQ'            : [501, get_id(), 'int'],
+                'pdb2mrcUnit'            : ['1 - 1/A, q=4pi*sin(th)/l)', get_id(), 'choice'],
+                'pdb2mrcSolvDensity'     : [0.334, get_id(), 'float'],
+                'pdb2mrcHydrDensity'     : [0.011, get_id(), 'float'],
+                'pdb2mrcFitSolvent'      : [True, get_id(), 'bool'],
+                'pdb2mrcFitShell'        : [True, get_id(), 'bool'],
+                'pdb2mrcVoxel'           : ['None', get_id(), 'text'],
+                'pdb2mrcSide'            : ['None', get_id(), 'text'],
+                'pdb2mrcNsamples'        : [128, get_id(), 'int'],
+
                 #Default structure prediction
-                'defaultStructureCalc'  : ['CRYSOL', get_id(), 'str'],
+                'defaultStructureCalc'  : ['PDB2SAS', get_id(), 'choice'],
 
                 #Weighted Average Settings
                 'weightCounter'         : ['', get_id(), 'choice'],
@@ -458,6 +474,10 @@ class RawGuiSettings(object):
                 'denssRefine'           : [True, get_id(), 'bool'],
                 'denssGPU'              : [False, get_id(), 'bool'],
 
+                #DIFT settings
+                # 'diftInitialAlpha'      : [0.0, get_id(), 'float'],
+                'diftExtrapolate'       : [True, get_id(), 'bool'],
+
                 #File definitions
                 'fileDefinitions'       : [file_defs, get_id(), 'dict'],
                 }
@@ -779,7 +799,7 @@ def postProcess(raw_settings, default_settings, loaded_param):
         raw_settings.set('IntegrationMethod', default_settings['IntegrationMethod'][0])
 
     dir_check_list = [('AutoSaveOnImageFiles', 'ProcessedFilePath'), ('AutoSaveOnAvgFiles', 'AveragedFilePath'),
-                    ('AutoSaveOnSub', 'SubtractedFilePath'), ('AutoSaveOnBift', 'BiftFilePath'),
+                    ('AutoSaveOnSub', 'SubtractedFilePath'), ('AutoSaveOnBift', 'BiftFilePath'), ('AutoSaveOnDift', 'DiftFilePath'),
                     ('AutoSaveOnGnom', 'GnomFilePath'), ('OnlineModeOnStartup', 'OnlineStartupDir'),
                     ]
 
@@ -794,6 +814,7 @@ def postProcess(raw_settings, default_settings, loaded_param):
                     'AutoSaveOnAvgFiles'    : '- AutoSave averaged files',
                     'AutoSaveOnSub'         : '- AutoSave subtracted files',
                     'AutoSaveOnBift'        : '- AutoSave BIFT files',
+                    'AutoSaveOnDift'        : '- AutoSave DIFT files',
                     'AutoSaveOnGnom'        : '- AutoSave GNOM files',
                     'OnlineModeOnStartup'   : '- Start online mode when RAW starts',
                     'NormFlatfieldEnabled'  : '- Apply a flatfield correction',
